#' @keywords internal
"_PACKAGE"

## usethis namespace: start
#' @importFrom doFuture %dofuture%
## usethis namespace: end
NULL

utils::globalVariables(c("i", "data"))
